@@ -895,6 +895,7 @@ windRose <- function(mydata, ws = "ws", wd = "wd", ws2 = NA, wd2 = NA,
             )
         }
         
+        
         if (annotate[1] == " ") {
           annotations_to_place <- 
             paste0(stat.lab2, " = ", dat$panel.fun[1])
@@ -909,6 +910,17 @@ windRose <- function(mydata, ws = "ws", wd = "wd", ws2 = NA, wd2 = NA,
             )
         }
         
+        # comparing two wind roses
+        if (diff) {
+          
+          annotate <- c("mean_ws" , "mean_wd")
+          annotations_to_place <- paste0(
+          mean_ws = paste("mean ws = ", round(as.numeric(dat$panel.fun[1]), 1)),
+          "\n",
+          mean_wd = paste("mean wd = ", round(dat$mean.wd[1], 1))
+          )
+        }
+        
         ltext(
           max.freq + off.set, -max.freq - off.set,
           label = annotations_to_place  ,
